cdef class SpellChecker:

    cpdef Sentence spellCheck(self, Sentence sentence):
        """
        The spellCheck method which takes a Sentence as an input.

        PARAMETERS
        ----------
        sentence : Sentence
            Sentence type input.

        RETURNS
        -------
        Sentence
            Sentence result.
        """
        pass
